# $Id: 004_check_processing2.t,v 1.2 2003/03/22 04:53:09 struan Exp $

use Test::More tests => 5;
use Foo2Mail;

my @mail1;

sub slurp {
    my $path = shift;
    open FILE, "<$path"; 
    if (wantarray) {
        my @data = <FILE>; close FILE; return @data;
    } else {
        my $data = join('',<FILE>); close FILE; return $data;
    }
}

@mail1 = grep { ! /^Date:/ } slurp('t/data/mail2.dat');

foreach my $dir (glob 't/test/*') {
    unlink <$dir/*>;
    rmdir $dir;
}

sub fetch {
    my ($self, $name, $target) = @_;

    my @foo;
    local $\ = undef;
    open FILE, "<$target" or die "couldn't open $target: $!";
    @foo = <FILE>;
    close FILE;

    # slight munging here as need to preserve \n in content but not id...
    my @vars = map { { name => $name, 
                       id => $target.$_ , 
                       content => $_, }; } @foo;

    return \@vars;
}

my %to_fetch = (
    test4   =>  't/data/test4.dat',
    test5   =>  't/data/test5.dat',
    test6   =>  't/data/test6.dat',
);

my $f2m = Foo2Mail->new(
    fetch           =>  \&fetch,
    to_fetch        =>  \%to_fetch,
    to              =>  'user@example.com',
    base_dir        =>  't/test',
    no_send         =>  1,
    include_errors  =>  1,
    warn_errors     =>  0,
   );

my $email = $f2m->get_email();
my @email = grep { ! /^Date:/ and ! /^X\-Mailer/ and ! /^Content-Length/ } split( /^/, $email);

is(join('', @email), join('', @mail1), 'correct email');

$f2m->store();

my $f2m2 = Foo2Mail->new(
    fetch           =>  \&fetch,
    to_fetch        =>  \%to_fetch,
    to              =>  'user@example.com',
    base_dir        =>  't/test',
    no_send         =>  1,
    include_errors  =>  1,
    warn_errors     =>  0,
   );

$email = $f2m2->get_email();
#warn $email;
ok(!$email,                             'no email without new content');

my $f2m3 = Foo2Mail->new(
    fetch           =>  \&fetch,
    to_fetch        =>  \%to_fetch,
    to              =>  'user@example.com',
    base_dir        =>  't/test',
    no_send         =>  1,
    include_errors  =>  1,
    always_new      =>  1,
    warn_errors     =>  0,
   );

$email = $f2m3->get_email();
#warn $email;
ok($email,                             'email with no new content and always_new ');

sub new_fetch {
    my ($self, $name, $target) = @_;
    my @content;
    for (1..10) {
        push @content, { id => $_, name => $name, subject => "$name: $_", content => 'foo' x $_ };
    }
    return \@content;
}

my $f2m4 = Foo2Mail->new(
    fetch           =>  \&new_fetch,
    to_fetch        =>  { foo => 'bar' },
    to              =>  'user@example.com',
    base_dir        =>  't/test',
    no_send         =>  1,
    include_errors  =>  1,
    always_new      =>  1,
    mail_items      =>  1,
    warn_errors     =>  0,
   );

is(scalar @{$f2m4->get_email()}, 10, 'mail_items option');

my $f2m5 = Foo2Mail->new(
    fetch           =>  \&new_fetch,
    to_fetch        =>  { foo => 'bar', bar => 'foo' },
    to              =>  'user@example.com',
    base_dir        =>  't/test',
    no_send         =>  1,
    include_errors  =>  1,
    always_new      =>  1,
    mail_each       =>  1,
    warn_errors     =>  0,
   );

is(scalar @{$f2m5->get_email()}, 2, 'mail_each option');
