# $Id: 005_bad_data.t,v 1.3 2003/03/30 11:05:35 struan Exp $

use Test::More tests => 10;
use Foo2Mail;

my $f2m = Foo2Mail->new();

is($f2m, undef, 'new returns undef if initialisation fails');

is($Foo2Mail::ERROR, 'Required params missing: fetch, to_fetch, to', 'missing required params');

$f2m = Foo2Mail->new(
    fetch   =>  {},
    to_fetch    =>  {},
    to  =>  '',
    no_auto =>  1,
);

is($Foo2Mail::ERROR, 'Parameter fetch is not a code reference', 'fetch not code ref');

$f2m = Foo2Mail->new(
    fetch   =>  sub {},
    to_fetch    =>  {},
    to  =>  '',
    no_auto =>  1,
);

is($Foo2Mail::ERROR, 'Parameter to_fetch must have at least one name, target pair', 'to_fetch no targets');

$f2m = Foo2Mail->new(
    fetch   =>  sub {},
    to_fetch    =>  {foo => 'bar'},
    to  =>  '',
    no_auto =>  1,
);

is($Foo2Mail::ERROR, 'Parameter to must have at least one email address', 'no to email');

$f2m = Foo2Mail->new(
    fetch   =>  sub {$_[0]->fatal_error('BOOM!')},
    to_fetch    =>  {foo => 'bar'},
    to  =>  'user@example.com',
    warn_errors   =>  0,
    no_send =>  1,
);

is($Foo2Mail::ERROR, 'BOOM!', 'Fails on call of fatal_error in fetch');

$f2m = Foo2Mail->new(
    fetch   =>  sub {},
    to_fetch    =>  {foo => 'bar'},
    to  =>  'user@example.com',
    no_send =>  1,
);

is($Foo2Mail::ERROR, '', 'ERROR cleared when re intialised');

$f2m = Foo2Mail->new(
    fetch   =>  sub {die "BOOM!"},
    to_fetch    =>  {foo => 'bar'},
    to  =>  'user@example.com',
    warn_errors   =>  0,
    no_send =>  1,
);

like($f2m->error, '/BOOM!/', 'catches problems in fetch code');

mkdir 't/test/test_ro';
chmod 0444, 't/test/test_ro';

$f2m = Foo2Mail->new(
    fetch   =>  sub {return { id => 1, name => 'foo', content => 'foo'} },
    to_fetch    =>  {foo => 'bar'},
    to  =>  'user@example.com',
    warn_errors   =>  0,
    no_send =>  1,
    base_dir => 't/test/test_ro',
);

$f2m->store();

like($f2m->error, '/Problem storing info/', 'catch failed write');

$f2m = Foo2Mail->new(
    fetch => sub { 
                    $_[0]->error('There was a problem');
                    return { id => 2, name => 'foo', content => 'foo' };
                 },
    to_fetch => { foo => 'bar' },
    to => 'user@example.com',
    no_send => 1,
    include_errors => 1,
    warn_errors => 0,
);

like($f2m->get_email(), '/There was a problem/', 'Errors included in email');

chmod 0755, 't/test/test_ro';
