# $Id: 009_check_storage.t,v 1.1 2003/03/22 04:53:10 struan Exp $

use Test::More tests => 7;
use Foo2Mail;

my $dir = 't/test/store_tests';

if (-e $dir) {
    unlink <$dir/*>;
}

sub fetch {
    my ($self, $name, $target) = @_;
    my @content;
    for (1..10) {
        push @content, { id => $_, name => $name, subject => "$name: $_", content => 'foo' x $_ };
    }
    return \@content;
}

sub show_ids {
    my $dir = shift;
    return join('', sort map { s#$dir/##; $_ } glob "$dir/*");
}

my $f2m = Foo2Mail->new(
    fetch       =>  \&fetch,
    to_fetch    =>  {foo => 'foo', bar => 'bar'},
    to          =>  'user@example.com',
    base_dir    =>  $dir,
    no_send     =>  1,
    warn_errors =>  0,
);

$f2m->store();

is(show_ids("$dir/foo"), '11023456789', 'foo ids stored');
is(show_ids("$dir/bar"), '11023456789', 'bar ids stored');

unlink <$dir/foo/*>;
unlink <$dir/bar/*>;

$f2m->store();

is(show_ids("$dir/foo"), '', 'foo ids not stored again');
is(show_ids("$dir/bar"), '', 'bar ids not stored again');

$f2m = Foo2Mail->new(
    fetch       =>  \&fetch,
    to_fetch    =>  {foo => 'foo', bar => 'bar'},
    to          =>  'user@example.com',
    base_dir    =>  $dir,
    no_send     =>  1,
    warn_errors =>  0,
    mail_each   =>  1,
);

$f2m->store(name => 'foo');
is(show_ids("$dir/foo"), '11023456789', 'foo ids stored on request');
is(show_ids("$dir/bar"), '', 'bar ids not stored');

$f2m->store(name => 'bar', id => { id => 2} );
is(show_ids("$dir/bar"), '2', 'requested bar id stored');
